ll-nightshade
=============

Serve the output of TOXIC functions/procedures with CherryPy__.

__ http://www.cherrypy.org/

For documentation read the source.

For requirements and installation instructions read ``INSTALL.rst``.

For a list of new features and bugfixes read ``NEWS.rst``.

For the license read ``nightshade.py``.

ll-nightshade is available from ftp://ftp.livinglogic.de/pub/livinglogic/nightshade/

Web pages can be found at http://www.livinglogic.de/Python/nightshade/

-- Walter Dörwald <walter@livinglogic.de>
